//Search for user agents with short names
//This here is matching the whole string like regexp m/\A$name\Z/i
dispMUA.arDispMUAAllocation["fullmatch"] =
{
  "yourzine" : [ "yourzine_nl.png" , "http://www.yourzine.nl/" ] ,
  "westcall" : [ "westcall.png" , "http://westcall.spb.ru/" ] ,
  "webmart" : [ "webmart.png" , "http://www.webmart.de/" ] ,
  "webmail" : [ "1und1-webmail.png" , "http://www.1und1.de/" ] ,
  "pixi" : [ "pixi.png" , "http://www.madgeniuses.net/pixi-versandhandelssoftware.html" ] ,
  "amlc" : [ "amlc.png" , "http://www.arclab.com/products/amlc/" ] ,
  "tin" : [ "tin.png" , "http://www.tin.org/" ] ,
  "php" : [ "php.png" , "http://www.php.net/" ] ,
  "mp5" : [ "mail-performance.png" , "http://www.mailperformance.com/" ] ,
  "mp6" : [ "mail-performance.png" , "http://www.mailperformance.com/" ] ,
  "fon" : [ "fon.png" , "http://www.fon.com/" ] ,
  "mh" : [ "gnu.png" , "http://www.gnu.org/software/mailutils/" ] ,
  "cr" : [ "cleverreach_de.png" , "http://www.cleverreach.de/" ] ,
}
